@@ -17,23 +17,23 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.4.6 (database v19.6)',
-	'GNUmed 1.4.6 Release Notes:
+	'Release Notes for GNUmed 1.4.9 (database v19.9)',
+	'GNUmed 1.4.9 Release Notes:
 
-	1.4.6
+	1.4.9
 
-FIX: missing qualification of make_pg_exception_fields_unicode() [thanks Khalil]
-FIX: missing method in TimeLine code
-FIX: bug in new-person EA validation code
-FIX: creating dummy identities used faulty gender
-FIX: faulty apparent_age formatting (age between 1-2 month ignored)
-FIX: attempt to use "chart review" encounter type even if it does not exist [thanks Jim]
+FIX: bug in current_meds placeholder
+FIX: utterly slow praxis branch PRW [thanks Jim]
+FIX: bug with changing praxis definition
 
-IMPROVED: DOB/age display in top panel
-IMPROVED: deal with display of missing gender
+	19.9 -- Requires PostgreSQL 9.1 !
+
+IMPROVED: add some indices to dem.org(_unit)
+IMPROVED: faster view for praxis branches
+IMPROVED: add pg_trgm extension
+IMPROVED: speed of dem.v_org_units
 
-	19.6 -- Requires PostgreSQL 9.1 !
 ');
 
 -- --------------------------------------------------------------
-select gm.log_script_insertion('v19-release_notes-dynamic.sql', '19.rc2');
+select gm.log_script_insertion('v19-release_notes-dynamic.sql', '19.8');
